@@ -104,18 +104,16 @@ void *result_worker( void * data ) {
 
 /* put back the result into the core */
 void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
-    int wsize, transportmode;
-    char *workload;
-    char *decrypted_data;
+    int transportmode;
+    const char *workload;
+    char *decrypted_data = NULL;
     char *decrypted_data_c;
-#ifdef GM_DEBUG
-    char *decrypted_orig;
-#endif
     struct timeval now, core_start_time;
     check_result * chk_result;
     int active_check = TRUE;
     char *ptr;
     double now_f, core_starttime_f, starttime_f, finishtime_f, exec_time, latency;
+    size_t wsize = 0;
 
     /* for calculating real latency */
     gettimeofday(&now,NULL);
@@ -128,22 +126,22 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
 
     /* get the data */
     wsize = gearman_job_workload_size(job);
-    workload = gm_malloc(sizeof(char*)*wsize+1);
-    strncpy(workload, (const char*)gearman_job_workload(job), wsize);
-    workload[wsize] = '\x0';
-    gm_log( GM_LOG_TRACE, "got result %s\n", gearman_job_handle( job ));
-    gm_log( GM_LOG_TRACE, "%zu +++>\n%s\n<+++\n", strlen(workload), workload );
+    workload = (const char *)gearman_job_workload(job);
+    if(workload == NULL) {
+        *ret_ptr = GEARMAN_WORK_FAIL;
+        return NULL;
+    }
+    gm_log( GM_LOG_TRACE, "got result %s\n", gearman_job_handle(job));
+    gm_log( GM_LOG_TRACE, "%zu +++>\n%.*s\n<+++\n", wsize, wsize, workload );
 
     /* decrypt data */
-    decrypted_data   = gm_malloc(wsize*2);
-    decrypted_data_c = decrypted_data;
-
     if(mod_gm_opt->transportmode == GM_ENCODE_AND_ENCRYPT && mod_gm_opt->accept_clear_results == GM_ENABLED) {
         transportmode = GM_ENCODE_ACCEPT_ALL;
     } else {
         transportmode = mod_gm_opt->transportmode;
     }
-    mod_gm_decrypt(result_ctx, &decrypted_data, workload, transportmode);
+    mod_gm_decrypt(result_ctx, &decrypted_data, workload, wsize, transportmode);
+    decrypted_data_c = decrypted_data;
 
     if(!strcmp(workload, "check")) {
         char * result = gm_malloc(GM_BUFFERSIZE);
@@ -168,10 +166,6 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
         return NULL;
     }
     gm_log( GM_LOG_TRACE, "%zu --->\n%s\n<---\n", strlen(decrypted_data), decrypted_data );
-#ifdef GM_DEBUG
-    decrypted_orig   = gm_strdup(decrypted_data);
-#endif
-    free(workload);
 
     /*
      * save this result to a file, so when nagios crashes,
@@ -193,10 +187,7 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
     /* naemon will free it after processing */
     if ( ( chk_result = ( check_result * )gm_malloc( sizeof *chk_result ) ) == 0 ) {
         *ret_ptr = GEARMAN_WORK_FAIL;
-#ifdef GM_DEBUG
-    free(decrypted_orig);
-#endif
-        free(decrypted_data);
+        gm_free(decrypted_data_c);
         return NULL;
     }
     init_check_result(chk_result);
@@ -231,8 +222,8 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
                 else
                     chk_result->output = gm_strdup( tmp_backslash );
 
-                free(tmp_newline);
-                free(tmp_backslash);
+                gm_free(tmp_newline);
+                gm_free(tmp_backslash);
             }
         }
 
@@ -271,9 +262,6 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
     if ( chk_result->host_name == NULL || chk_result->output == NULL ) {
         *ret_ptr= GEARMAN_WORK_FAIL;
         gm_log( GM_LOG_ERROR, "discarded invalid job (%s), check your encryption settings\n", gearman_job_handle( job ) );
-#ifdef GM_DEBUG
-    free(decrypted_orig);
-#endif
         return NULL;
     }
 
@@ -319,15 +307,6 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
     chk_result->check_options    = chk_result->check_options & ! CHECK_OPTION_FRESHNESS_CHECK;
 
     if ( chk_result->service_description != NULL ) {
-#ifdef GM_DEBUG
-        /* does this services exist */
-        service * svc = find_service( chk_result->host_name, chk_result->service_description );
-        if(svc == NULL) {
-            write_debug_file(&decrypted_orig);
-            gm_log( GM_LOG_ERROR, "service '%s' on host '%s' could not be found\n", chk_result->service_description, chk_result->host_name );
-            return NULL;
-        }
-#endif
         gm_log( GM_LOG_DEBUG, "service job completed: %s %s: exit %d, latency: %0.3f, exec_time: %0.3f\n", chk_result->host_name, chk_result->service_description, chk_result->return_code, chk_result->latency, exec_time );
     } else {
         if(active_check) {
@@ -345,10 +324,7 @@ void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *contex
     /* reset pointer */
     chk_result = NULL;
 
-    free(decrypted_data_c);
-#ifdef GM_DEBUG
-    free(decrypted_orig);
-#endif
+    gm_free(decrypted_data_c);
 
     return NULL;
 }
@@ -383,19 +359,3 @@ int set_worker( gearman_worker_st **worker ) {
 
     return GM_OK;
 }
-
-#ifdef GM_DEBUG
-/* write text to a debug file */
-void write_debug_file(char ** text) {
-    FILE * fd;
-    fd = fopen( "/tmp/mod_gearman_result.txt", "a+" );
-    if(fd == NULL) {
-        perror("fopen");
-    } else {
-        fputs( "------------->\n", fd );
-        fputs( *text, fd );
-        fputs( "\n<-------------\n", fd );
-        fclose( fd );
-    }
-}
-#endif
